==> pierogi_1.1.19.tar.gz: pierogi-1.1.19/keysets/samsung.h <==
#ifndef SAMSUNG_H
#define SAMSUNG_H

#include "pirkeysetmetadata.h"
#include "pirackeyset.h"

class QObject;

class SamsungTV1: public PIRKeysetMetaData
{
public:
  SamsungTV1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungTV1a: public SamsungTV1
{
public:
  SamsungTV1a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungTV1b: public SamsungTV1
{
public:
  SamsungTV1b(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungTV1c: public SamsungTV1
{
public:
  SamsungTV1c(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungTV1d: public SamsungTV1
{
public:
  SamsungTV1d(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungTV1e: public SamsungTV1
{
public:
  SamsungTV1e(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungTV1f: public SamsungTV1
{
public:
  SamsungTV1f(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungTV2: public PIRKeysetMetaData
{
public:
  SamsungTV2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungTV2a: public SamsungTV2
{
public:
  SamsungTV2a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungVCR1: public PIRKeysetMetaData
{
public:
  SamsungVCR1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungVCR1a: public SamsungVCR1
{
public:
  SamsungVCR1a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungVCR1b: public SamsungVCR1
{
public:
  SamsungVCR1b(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungVCR1c: public SamsungVCR1a
{
public:
  SamsungVCR1c(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungVCR1d: public SamsungVCR1
{
public:
  SamsungVCR1d(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungVCR1e: public SamsungVCR1
{
public:
  SamsungVCR1e(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungDVD1: public PIRKeysetMetaData
{
public:
  SamsungDVD1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungDVD1a: public SamsungDVD1
{
public:
  SamsungDVD1a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungDVD1b: public SamsungDVD1
{
public:
  SamsungDVD1b(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungDVD2: public PIRKeysetMetaData
{
public:
  SamsungDVD2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungAC1: public PIRKeysetMetaData
{
public:
  SamsungAC1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungAC2: public PIRACKeyset
{
public:
  SamsungAC2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void getTurboModePairs(
    PIRStatePairs &turboModePairs) const;

  virtual void getSwingPairs(
    PIRStatePairs &swingPairs) const;

  virtual void getTemperaturePairs(
    PIRStatePairs &temperaturePairs) const;

  virtual void getFanPairs(
    PIRStatePairs &fanPairs) const;

  virtual void getModePairs(
    PIRStatePairs &modePairs) const;

  virtual void getAirCleanPairs(
    PIRStatePairs &aircleanPairs) const;

  virtual void getPowerPairs(
    PIRStatePairs &powerPairs) const;

  virtual void getTimerOptionPairs(
    PIRStatePairs &timerOptionPairs) const;
};

class SamsungDVBT1: public PIRKeysetMetaData
{
public:
  SamsungDVBT1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

#endif // SAMSUNG_H

==> pierogi_1.1.20.tar.gz: pierogi-1.1.20/keysets/samsung.h <==
#ifndef SAMSUNG_H
#define SAMSUNG_H

#include "pirkeysetmetadata.h"
#include "pirackeyset.h"

class QObject;

class SamsungTV1: public PIRKeysetMetaData
{
public:
  SamsungTV1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungTV1a: public SamsungTV1
{
public:
  SamsungTV1a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungTV1b: public SamsungTV1
{
public:
  SamsungTV1b(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungTV2: public PIRKeysetMetaData
{
public:
  SamsungTV2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungTV3: public PIRKeysetMetaData
{
public:
  SamsungTV3(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungTV3a: public SamsungTV3
{
public:
  SamsungTV3a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungVCR1: public PIRKeysetMetaData
{
public:
  SamsungVCR1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};


class SamsungVCR1a: public SamsungVCR1
{
public:
  SamsungVCR1a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungVCR1b: public SamsungVCR1
{
public:
  SamsungVCR1b(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungVCR1c: public SamsungVCR1a
{
public:
  SamsungVCR1c(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungVCR1d: public SamsungVCR1
{
public:
  SamsungVCR1d(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungVCR1e: public SamsungVCR1
{
public:
  SamsungVCR1e(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungDVD1: public PIRKeysetMetaData
{
public:
  SamsungDVD1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungDVD1a: public SamsungDVD1
{
public:
  SamsungDVD1a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungDVD1b: public SamsungDVD1
{
public:
  SamsungDVD1b(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungDVD2: public PIRKeysetMetaData
{
public:
  SamsungDVD2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungAC1: public PIRKeysetMetaData
{
public:
  SamsungAC1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class SamsungAC2: public PIRACKeyset
{
public:
  SamsungAC2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void getTurboModePairs(
    PIRStatePairs &turboModePairs) const;

  virtual void getSwingPairs(
    PIRStatePairs &swingPairs) const;

  virtual void getTemperaturePairs(
    PIRStatePairs &temperaturePairs) const;

  virtual void getFanPairs(
    PIRStatePairs &fanPairs) const;

  virtual void getModePairs(
    PIRStatePairs &modePairs) const;

  virtual void getAirCleanPairs(
    PIRStatePairs &aircleanPairs) const;

  virtual void getPowerPairs(
    PIRStatePairs &powerPairs) const;

  virtual void getTimerOptionPairs(
    PIRStatePairs &timerOptionPairs) const;
};

class SamsungDVBT1: public PIRKeysetMetaData
{
public:
  SamsungDVBT1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

#endif // SAMSUNG_H
